==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/VolumeClaimSpecSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * VolumeClaimSpecSelector properties
 * @property matchExpressions MatchExpressions is a list of label selector requirements. The requirements are ANDed.
 * @property matchLabels MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
 */
public data class VolumeClaimSpecSelectorArgs(
    public val matchExpressions: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>? = null,
    public val matchLabels: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs.builder()
            .matchExpressions(
                matchExpressions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .matchLabels(
                matchLabels?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [VolumeClaimSpecSelectorArgs].
 */
@PulumiTagMarker
public class VolumeClaimSpecSelectorArgsBuilder internal constructor() {
    private var matchExpressions: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>? = null

    private var matchLabels: Output<Map<String, String>>? = null

    /**
     * @param value MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("mtobolvqgvifujax")
    public suspend
    fun matchExpressions(`value`: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>) {
        this.matchExpressions = value
    }

    @JvmName("kpssvvkheiegjrcv")
    public suspend fun matchExpressions(
        vararg
        values: Output<VolumeClaimSpecSelectorMatchExpressionsArgs>,
    ) {
        this.matchExpressions = Output.all(values.asList())
    }

    /**
     * @param values MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("bgmhfahgpxljxxvp")
    public suspend
    fun matchExpressions(values: List<Output<VolumeClaimSpecSelectorMatchExpressionsArgs>>) {
        this.matchExpressions = Output.all(values)
    }

    /**
     * @param value MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("orrrbjeyfdkyfhgs")
    public suspend fun matchLabels(`value`: Output<Map<String, String>>) {
        this.matchLabels = value
    }

    /**
     * @param value MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("wbcbossayggfabqp")
    public suspend fun matchExpressions(`value`: List<VolumeClaimSpecSelectorMatchExpressionsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("pcpbyharabbecvqo")
    public suspend
    fun matchExpressions(argument: List<suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("bswowxikuwcaxitj")
    public suspend fun matchExpressions(
        vararg
        argument: suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("noqftshissgilbiw")
    public suspend
    fun matchExpressions(argument: suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param values MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("dbkewjulqlecichx")
    public suspend fun matchExpressions(vararg values: VolumeClaimSpecSelectorMatchExpressionsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchExpressions = mapped
    }

    /**
     * @param value MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("gottssgqmxefqjre")
    public suspend fun matchLabels(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchLabels = mapped
    }

    /**
     * @param values MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("wlrfjfibdteydmko")
    public fun matchLabels(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchLabels = mapped
    }

    internal fun build(): VolumeClaimSpecSelectorArgs = VolumeClaimSpecSelectorArgs(
        matchExpressions = matchExpressions,
        matchLabels = matchLabels,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/VolumeClaimSpecSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * VolumeClaimSpecSelector properties
 * @property matchExpressions MatchExpressions is a list of label selector requirements. The requirements are ANDed.
 * @property matchLabels MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
 */
public data class VolumeClaimSpecSelectorArgs(
    public val matchExpressions: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>? = null,
    public val matchLabels: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimSpecSelectorArgs.builder()
            .matchExpressions(
                matchExpressions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .matchLabels(
                matchLabels?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [VolumeClaimSpecSelectorArgs].
 */
@PulumiTagMarker
public class VolumeClaimSpecSelectorArgsBuilder internal constructor() {
    private var matchExpressions: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>? = null

    private var matchLabels: Output<Map<String, String>>? = null

    /**
     * @param value MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("vflrhrlhfawddcdb")
    public suspend
    fun matchExpressions(`value`: Output<List<VolumeClaimSpecSelectorMatchExpressionsArgs>>) {
        this.matchExpressions = value
    }

    @JvmName("aqdarjsilqjbtdvs")
    public suspend fun matchExpressions(
        vararg
        values: Output<VolumeClaimSpecSelectorMatchExpressionsArgs>,
    ) {
        this.matchExpressions = Output.all(values.asList())
    }

    /**
     * @param values MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("shyxynojyywlkicb")
    public suspend
    fun matchExpressions(values: List<Output<VolumeClaimSpecSelectorMatchExpressionsArgs>>) {
        this.matchExpressions = Output.all(values)
    }

    /**
     * @param value MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("otboxilanohtqnkc")
    public suspend fun matchLabels(`value`: Output<Map<String, String>>) {
        this.matchLabels = value
    }

    /**
     * @param value MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("neihljelrxpvnxen")
    public suspend fun matchExpressions(`value`: List<VolumeClaimSpecSelectorMatchExpressionsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("yniaedndafaicgni")
    public suspend
    fun matchExpressions(argument: List<suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("ahoryidragxnopeh")
    public suspend fun matchExpressions(
        vararg
        argument: suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param argument MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("rfbvbotnvkgcehyg")
    public suspend
    fun matchExpressions(argument: suspend VolumeClaimSpecSelectorMatchExpressionsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VolumeClaimSpecSelectorMatchExpressionsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchExpressions = mapped
    }

    /**
     * @param values MatchExpressions is a list of label selector requirements. The requirements are ANDed.
     */
    @JvmName("gqlsvwwlgssgtawr")
    public suspend fun matchExpressions(vararg values: VolumeClaimSpecSelectorMatchExpressionsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchExpressions = mapped
    }

    /**
     * @param value MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("uejosulmdmsqhdfx")
    public suspend fun matchLabels(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchLabels = mapped
    }

    /**
     * @param values MatchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    @JvmName("ygafixcrusdwtlwb")
    public fun matchLabels(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchLabels = mapped
    }

    internal fun build(): VolumeClaimSpecSelectorArgs = VolumeClaimSpecSelectorArgs(
        matchExpressions = matchExpressions,
        matchLabels = matchLabels,
    )
}
